@@ -2,7 +2,11 @@
 # username and password over HTTP BASIC authentication.
 
 from collections import Counter
+from typing import cast
+
 from jira import JIRA
+from jira.client import ResultList
+from jira.resources import Issue
 
 # By default, the client will connect to a Jira instance started from the Atlassian Plugin SDK.
 # See
@@ -15,7 +19,9 @@ jira = JIRA(basic_auth=("admin", "admin"))  # a username/password tuple
 props = jira.application_properties()
 
 # Find all issues reported by the admin
-issues = jira.search_issues("assignee=admin")
+# Note: we cast() for mypy's benefit, as search_issues can also return the raw json !
+#   This is if the following argument is used: `json_result=True`
+issues = cast(ResultList[Issue], jira.search_issues("assignee=admin"))
 
 # Find the top three projects containing issues reported by admin
 top_three = Counter([issue.fields.project.key for issue in issues]).most_common(3)
